import React from 'react';
declare const FormatType: ["-", ":", "empty"];
declare type Format = typeof FormatType[number];
export interface Params {
    start?: string | number | RegExp;
    end?: string | number | RegExp;
    format?: Format | Array<Format>;
    special?: Array<string>;
    excludeRegExp?: RegExp;
    range?: Array<number>;
    includeIp?: boolean;
    protocol?: 'http' | 'https' | 'both';
    protocolRequired?: boolean;
    dateFormat?: string;
}
interface Rule {
    message?: React.ReactNode;
    params?: Params;
    [prop: string]: any;
}
/**
 * IP地址校验
 * @param rule { message: string; params?: {start: string|number|RegExp, end: string|number|RegExp }
 *  end 最后一位匹配内容；字符串只能为以下两种写法：0 or 0-255
 *  start 暂时未使用
 * @param value
 * @param callback
 */
export declare function ip(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 子网掩码校验
 * @param rule { message: string; params?: {start: string|number|RegExp, end: string|number|RegExp }} 若不传params，则最后一位默认为：0 - 254
 *  end: 最后一位匹配内容；字符串只能为以下两种写法：0 or 0-255
 *  start: 暂时未使用
 * @param value
 * @param callback
 */
export declare function mask(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 校验mac地址
 * @param rule { message: string; params?: {params: { format: [':','-', 'empty'], special: ['00:00:00:00:00:00','']}} 若不传params，则默认支持:格式，默认全0 mac为false
 *  format: 支持格式为：冒号，-，和纯字符(empty)的数组集合
 *  special：表示特殊支持mac
 * @param value
 * @param callback
 */
export declare function mac(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 校验ssid
 * @param rule { message: string; params?: {range, excludeRegExp} 若不传params，则默认支持:格式，默认全0 mac为false
 *  range: 长度范围
 *  excludeRegExp: 特殊匹配，不支持的内容 ？是否需要这个字段？
 * @param value
 * @param callback
 */
export declare function ssid(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 校验wifi密码
 * @param rule { message: string; params?: {}
 * @param value
 * @param callback
 */
export declare function ssidPwd(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 校验ascii
 * @param rule { message: string; params?: {range}
 *  range: 长度范围
 * @param value
 * @param callback
 */
export declare function ascii(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 校验hex
 * @param rule { message: string; params?: {params: {range }}
 *  range: 长度范围
 * @param value
 * @param callback
 */
export declare function hex(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 校验字符字节长度
 * @param rule { message: string; params?: { range: []}}
 * @param value
 * @param callback
 */
export declare function byteLen(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 校验值的范围
 *
 * @export
 * @param {Rule} rule { message: string; params?: { range: [min, max]}}
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */
export declare function numRange(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 邮箱地址校验
 * @param rule { message: string; }
 * @param value
 * @param callback
 */
export declare function email(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 域名校验
 * @export
 * @param {Rule} rule { message: string, params: { special: Array<string>; includeIp: boolean } }
 *  includeIp:表示域名是否包含ip，true：包含IP，false：不包含IP，默认为 true
 *  special: 表示允许的特殊数据
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */
export declare function domain(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * URL地址完整校验
 * @export
 * @param {Rule} rule { message: string, params: { protocol: string, protocolRequired: boolean } }
 * protocol: 支持的協議，http,https or both
 * protocolRequired: 協議是否必填，默認為false
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */
export declare function url(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 服务名和服务器名
 *
 * @export
 * @param {Rule} rule
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */
export declare function serverName(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
/**
 * 日期格式校验
 *
 * @export
 * @param {Rule} rule { message: string, params: { dateFormat: 'yyyy-MM-dd hh:mm:ss'},  }
 * @param {string} value
 * @param {(error?: string) => void} callback
 * @returns {boolean}
 */
export declare function date(rule: Rule, value: string, callback: (error?: React.ReactNode) => void): boolean;
export {};
