"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TYPE_VALUE_RESOLVER_MAP = exports.RANGE_PARSER = exports.RANGE_FORMATTER = exports.PLACEMENT_MAP = exports.HAVE_TRIGGER_TYPES = exports.DEFAULT_FORMATS = exports.DATE_PARSER = exports.DATE_FORMATTER = void 0;

var _utils = require("./utils");

var DEFAULT_FORMATS = {
  date: 'yyyy-MM-dd',
  month: 'yyyy-MM',
  year: 'yyyy',
  week: 'yyyywWW',
  time: 'HH:mm:ss',
  timerange: 'HH:mm:ss',
  daterange: 'yyyy-MM-dd'
};
exports.DEFAULT_FORMATS = DEFAULT_FORMATS;
var HAVE_TRIGGER_TYPES = ['date', 'time', 'week', 'month', 'year', 'daterange', 'timerange'];
/**
 * 获取date格式化之后的数据
 * @param value 原数据 Date
 * @param format 格式化string
 * @returns value格式化后的数据
 */

exports.HAVE_TRIGGER_TYPES = HAVE_TRIGGER_TYPES;

var DATE_FORMATTER = function DATE_FORMATTER(value, format) {
  return (0, _utils.formatDate)(value, format);
};

exports.DATE_FORMATTER = DATE_FORMATTER;

var DATE_PARSER = function DATE_PARSER(text, format) {
  return (0, _utils.parseDate)(text, format);
};
/**
 * 将Date格式的数据转换为string数组
 * @param value Date[]
 * @param format string
 * @returns string[]
 */


exports.DATE_PARSER = DATE_PARSER;

var RANGE_FORMATTER = function RANGE_FORMATTER(value, format) {
  if (Array.isArray(value) && value.length === 2) {
    var start = value[0];
    var end = value[1];
    return [(0, _utils.formatDate)(start, format), (0, _utils.formatDate)(end, format)];
  }

  return null;
};

exports.RANGE_FORMATTER = RANGE_FORMATTER;

var RANGE_PARSER = function RANGE_PARSER(text, format) {
  if (text.length === 2) {
    var range1 = text[0];
    var range2 = text[1];
    return [(0, _utils.parseDate)(range1, format), (0, _utils.parseDate)(range2, format)];
  }

  return [];
};

exports.RANGE_PARSER = RANGE_PARSER;
var TYPE_VALUE_RESOLVER_MAP = {
  /**
   * 默认处理
   */
  default: {
    /**
     * 格式化value
     * @param value string
     * @returns string
     */
    formatter: function formatter(value) {
      if (!value) {
        return '';
      }

      return '' + value;
    },

    /**
     * 格式化text
     * @param text string|Date
     * @returns string|Date
     */
    parser: function parser(text) {
      if (text === undefined || text === '') {
        return null;
      }

      return text;
    }
  },

  /**
   * 周
   */
  week: {
    /**
     * 获取string类型的周
     * @param value Date 需要格式化的值
     * @param format string 格式化
     * @returns string
     */
    formatter: function formatter(value, format) {
      if (value instanceof Date) {
        /**没有格式化字段， */
        if (!format) {
          /**获取value值在一年中处于第几周 */
          var weekNumber = (0, _utils.getWeekNumber)(value);
          /**返回年+w+周 */

          return value.getFullYear() + 'w' + (weekNumber > 9 ? weekNumber : '0' + weekNumber);
        } else {
          /**str为string，得到value格式化后的数据 */
          var str = DATE_FORMATTER(value, format);

          if (str !== '') {
            /** 获取周 */
            var weekno = (0, _utils.deconstructDate)(value).week;
            var ww = weekno < 10 ? "0".concat(weekno) : "".concat(weekno);
            str = str;
            /**年+周 */

            str = /WW/.test(str) ? str.replace(/WW/, ww) : str.replace(/W/, "".concat(weekno));
          }

          return str;
        }
      }

      return '';
    },

    /**
     * 获取date类型的周
     * yyyywWW  根据format yyyywWW 格式，获取WW周出现的位置，根据位置获取到传入的周数和年份，根据周和年份计算出所在的日期（Date格式）
     * @param text 
     * @param format 
     * @returns Date
     */
    parser: function parser(text, format) {
      var weekno = function weekno(matcher, src) {
        //str为周
        var str = src.substr(matcher.index, matcher.length);

        if (/\d\d?/.test(str)) {
          return {
            week: Number(str),
            isValid: true
          };
        } else {
          return {
            week: -1,
            isValid: false
          };
        }
      };
      /**格式化 text string===>Date*/


      var date = DATE_PARSER(text, format);
      var matcher = format.match(/(WW?)/);
      var wn = null;

      if (!matcher) {
        return date;
      } else {
        //格式错误返回空
        if (text.length > format.length) {
          return '';
        }

        switch (matcher.length) {
          case 1:
            wn = weekno(matcher, text);

            if (!wn.isValid) {
              return '';
            }

            break;

          case 2:
            wn = weekno(matcher, text);

            if (!wn.isValid) {
              return '';
            }

            break;

          default:
            throw new Error('never reach here');
        }
        /**根据周，年得到Date具体哪一天 */


        return (0, _utils.getDateOfISOWeek)(wn.week, typeof date !== 'boolean' && date.getFullYear());
      }
    }
  },

  /**
   * 日期
   */
  date: {
    formatter: DATE_FORMATTER,
    //日期格式化为string
    parser: DATE_PARSER //日期格式化为Date

  },

  /**
   * 日期+时间
   */
  // datetime: {
  //     formatter: DATE_FORMATTER,//日期格式化为string
  //     parser: DATE_PARSER//日期格式化为Date
  // },

  /**
   * 日期范围
   */
  daterange: {
    formatter: RANGE_FORMATTER,
    //日期格式化为string[]
    parser: RANGE_PARSER //日期格式化为Date[]

  },

  /**
   * 日期时间范围
   */
  // datetimerange: {
  //     formatter: RANGE_FORMATTER,//日期格式化为string[]
  //     parser: RANGE_PARSER//日期格式化为Date[]
  // },

  /**
   * 时间范围
   */
  timerange: {
    formatter: RANGE_FORMATTER,
    //日期格式化为string[]
    parser: RANGE_PARSER //日期格式化为Date[]

  },

  /**
   * 时间
   */
  time: {
    formatter: DATE_FORMATTER,
    //日期格式化为string
    parser: DATE_PARSER //日期格式化为Date

  },

  /**
   *月
   */
  month: {
    formatter: DATE_FORMATTER,
    //日期格式化为string
    parser: DATE_PARSER //日期格式化为Date

  },

  /**
   * 年
   */
  year: {
    formatter: DATE_FORMATTER,
    //日期格式化为string
    parser: DATE_PARSER //日期格式化为Date

  },

  /**
   * 数字
   */
  number: {
    formatter: function formatter(value) {
      if (!value) {
        return '';
      }

      return '' + value;
    },
    parser: function parser(text) {
      var result = Number(text);

      if (!isNaN(text)) {
        return result;
      } else {
        return null;
      }
    }
  }
};
exports.TYPE_VALUE_RESOLVER_MAP = TYPE_VALUE_RESOLVER_MAP;
var PLACEMENT_MAP = {
  left: 'bottom-start',
  center: 'bottom-center',
  right: 'bottom-end'
};
exports.PLACEMENT_MAP = PLACEMENT_MAP;