import * as React from 'react';
import { Position } from './Form';
import { ObjectType } from "../../libs/types";
import { Params } from "../../libs/utils/validator";
export declare type RuleType = 'string' | 'number' | 'boolean' | 'method' | 'regexp' | 'integer' | 'float' | 'array' | 'object' | 'enum' | 'date' | 'url' | 'hex' | 'email' | 'any';
export interface ValidateOption {
    suppressWarning?: boolean;
    first?: boolean;
    firstFields?: boolean | string[];
}
/**
 * 自定义规则的
 */
interface CustomItemRule {
    date?: true | Params;
    serverName?: true | Params;
    url?: true | Params;
    domain?: true | Params;
    email?: true | Params;
    numRange?: true | Params;
    byteLen?: true | Params;
    hex?: true | Params;
    ascii?: true | Params;
    ssidPwd?: true | Params;
    ssid?: true | Params;
    mac?: true | Params;
    mask?: true | Params;
    ip?: true | Params;
    params?: Params;
}
export interface ItemRule extends CustomItemRule {
    type?: RuleType;
    required?: boolean;
    /**正则表达式匹配**/
    pattern?: RegExp | string;
    /**必须设置 type：string 类型为字符串最小长度；number 类型时为最小值；array 类型时为数组最小长度**/
    min?: number;
    /**必须设置 type：string 类型为字符串最大长度；number 类型时为最大值；array 类型时为数组最大长度**/
    max?: number;
    /**string 类型时为字符串长度；number 类型时为确定数字； array 类型时为数组长度**/
    len?: number;
    /**是否匹配枚举中的值（需要将 type 设置为 enum）**/
    enum?: Array<string | number | boolean | null | undefined>;
    /**如果字段仅包含空格则校验不通过**/
    whitespace?: boolean;
    fields?: Rules;
    options?: ValidateOption;
    defaultField?: {
        type: RuleType;
    };
    /**将字段值转换成目标值后进行校验**/
    transform?: (value: any) => any;
    message?: React.ReactNode;
    trigger?: 'blur' | 'change';
    asyncValidator?: (rule: Rules, value: any, callback: (error: string | string[] | void) => void, source: ObjectType, options: ValidateOption) => void | Promise<void>;
    validator?: (rule: Rules, value: any, callback: (error?: React.ReactNode) => void, source: ObjectType, options: ValidateOption) => void;
}
export interface Rules {
    [key: string]: Array<ItemRule>;
}
export interface FormItemProps {
    disabled?: boolean;
    style?: React.CSSProperties;
    className?: string;
    label?: string | React.ReactElement;
    labelWidth?: string | number;
    labelPosition?: Position;
    required?: boolean;
    rules?: Array<ItemRule>;
    prop?: string;
    children?: React.ReactNode;
    /**校验状态，如不设置，则会根据校验规则自动生成**/
    validateStatus?: 'success' | 'warning' | 'error' | 'validating';
    /**校验信息，如不设置，则会根据校验规则自动生成**/
    validateMessage?: string;
    /**如果Form的labelWidth不设置
     * 那么Form的labelWidth会自动计算为下面FormItem的label的最大值
     * 这个autoComputeMaxLabel 如果设置为false 可以让这个FormItem不参与计算
     **/
    autoComputeMaxLabel?: boolean;
}
export interface FormItemStates {
    error?: string;
    valid?: boolean;
    validating?: boolean;
    validated?: boolean;
    children?: React.ReactElement;
    _prevProps?: FormItemProps;
}
export interface ItemValidResult {
    valid: boolean;
    message?: string;
    field?: string;
}
export default class FormItem extends React.Component<FormItemProps, FormItemStates> {
    static defaultProps: {
        autoComputeMaxLabel: boolean;
    };
    static contextType: React.Context<any>;
    state: {
        error: string;
        valid: boolean;
        validated: boolean;
        validating: boolean;
    };
    label: HTMLLabelElement;
    /*** KeyList 操作*/
    private _keyList;
    /**判断组件是否卸载**/
    private _isMounted;
    /**
     * 安全的设置state
     * @param state
     * @param callback
     */
    safeSetState(state: FormItemStates, callback?: any): void;
    /**
     * 第一次挂载
     */
    componentDidMount(): void;
    /**
     * 组件卸载
     */
    componentWillUnmount(): void;
    /**
     * 在FormItem失去焦点时
     */
    handleFieldBlur(): Promise<void>;
    /**
     * 在FormItem中的input等值改变时
     */
    handleFieldInput(): Promise<void>;
    /**
     * 得到规则
     */
    getRules(): Array<ItemRule>;
    /**
     *根据触发类型得到指定的rule
     * @param trigger
     */
    getFilteredRule(trigger: string): Array<ItemRule>;
    /**
     * 重置当前FormItem
     */
    resetField(): void;
    /**
     * 添加自定义的规则
     * @param rules
     */
    static addCustomRules(rules: Array<ItemRule>, value: any): Array<ItemRule>;
    /**
     * 更新校验
     * @param prevProps
     * @param prevState
     */
    componentDidUpdate(prevProps: FormItemProps, prevState: FormItemStates): void;
    /**
     * 当前FormItem验证
     * @param trigger
     * @param cb
     */
    validate(trigger: string, cb?: (result: ItemValidResult) => void): Promise<ItemValidResult>;
    /**
     * 得到当前name指定的值
     */
    fieldValue(): ObjectType;
    /**
     * 是否是需要的
     */
    isRequired(): boolean;
    /**
     * 获取labelPosition
     */
    getLabelPosition(): "right" | "left" | "center" | "top";
    /***
     * 根据validateStatus 生成icon
     */
    getIconByValidateStatus(): React.ReactElement;
    /**
     * 渲染suffix
     */
    renderSuffix(): {
        onClick?: () => void;
        className?: string;
        children: React.ReactElement;
    };
    /**
     * 计算className
     */
    getClassNames(isRequired: boolean): string;
    /**
     * 获取computedStyle
     */
    getComputedOuterStyle(labelPosition: string): React.CSSProperties;
    /**
     * KeyList 操作
     */
    keyList(): {
        length: () => number;
        index: (key: string) => number;
        add: (key: string) => void;
        remove: (key: string) => void;
    };
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
