import * as React from 'react';
import { Base, ForwardRef, ObjectType, RefObject, Size } from '../../libs/types';
export declare type InputSize = Size;
declare const InputResizeTypes: ["none", "both", "horizontal", "vertical"];
export declare type InputResize = typeof InputResizeTypes[number];
export interface Slot extends React.DOMAttributes<HTMLSpanElement>, Base {
    style?: React.CSSProperties;
    className?: string;
    children?: React.ReactNode;
    onClick?: (event: React.MouseEvent<HTMLSpanElement>) => void;
}
export interface PasswordType extends React.DOMAttributes<HTMLSpanElement> {
    style?: React.CSSProperties;
    className?: string;
    /**是否显示切换密码图标**/
    showPassword?: boolean;
    /**是否在input获得焦点改变密码为明文失去焦点变成密文**/
    focusBlurChangePasswordType?: boolean;
    icon?: React.ReactNode;
    onSwitch?: (boolean: boolean) => void;
}
interface ExtraAttributes extends React.InputHTMLAttributes<HTMLInputElement> {
    autoComplete?: string;
    autoFocus?: boolean;
    cols?: number;
    dirName?: string;
    disabled?: boolean;
    form?: string;
    maxLength?: number;
    minLength?: number;
    name?: string;
    placeholder?: string;
    readOnly?: boolean;
    required?: boolean;
    rows?: number;
    value?: string | ReadonlyArray<string> | number;
    wrap?: string;
    onChange?: React.ChangeEventHandler<HTMLElement>;
}
export interface InputBaseProps extends Omit<ExtraAttributes, 'size' | 'prefix' | 'cols' | 'rows'> {
    ellipsis?: boolean;
    /**title**/
    title?: string;
    /**原生type属性**/
    type?: string;
    /**可以点击清除图标删除内容**/
    allowClear?: boolean;
    /**是否有边框**/
    bordered?: boolean;
    /**是否禁用**/
    disabled?: boolean;
    /**名称**/
    name?: string;
    /**placeholder提示**/
    placeholder?: string;
    /**是否可读**/
    readOnly?: boolean;
    /**自动聚焦**/
    autoFocus?: boolean;
    /**最大长度**/
    maxLength?: number;
    /**是否显示最大长度的文本**/
    maxLengthTextVisible?: boolean;
    /**最小长度**/
    minLength?: number;
    /**值**/
    value?: string | number;
    /**可以使用正则去匹配哪些可以输入**/
    regexp?: RegExp | ((value: string) => boolean);
    /**是否去除值首位2端的空格**/
    trim?: boolean;
    /**根据内容自适应宽度 ps:改方法只有在绑定了value才会生效**/
    fitSize?: boolean;
    /**样式**/
    style?: React.CSSProperties;
    /**类名称**/
    className?: string;
    /**尺寸大小**/
    size?: InputSize;
    /**前缀自定义--位于边框内部**/
    prefix?: React.ReactNode | Slot | Array<Slot>;
    /**后缀自定义--位于边框内部**/
    suffix?: React.ReactNode | Slot | Array<Slot>;
    /**前缀自定义--位于边框外部**/
    prepend?: React.ReactNode;
    /**后缀自定义--位于边框外部**/
    append?: React.ReactNode;
    /**表单校验显示状态图标**/
    status?: Slot;
    /**默认值**/
    defaultValue?: string | number;
    /**获得焦点的事件**/
    onFocus?: React.FocusEventHandler<HTMLInputElement | HTMLTextAreaElement>;
    /**失去焦点的事件**/
    onBlur?: React.FocusEventHandler<HTMLInputElement | HTMLTextAreaElement>;
    /**值改变的事件**/
    onChange?: React.ChangeEventHandler<HTMLInputElement | HTMLTextAreaElement>;
    /**鼠标移入事件**/
    onMouseEnter?: React.MouseEventHandler<HTMLElement>;
    /**鼠标离开事件**/
    onMouseLeave?: React.MouseEventHandler<HTMLElement>;
    /**点击事件**/
    onClick?: React.MouseEventHandler<HTMLDivElement>;
    onClear?: React.MouseEventHandler<HTMLElement>;
    /**校验后的回调**/
    onRegexp?: (result: boolean, value?: string) => void;
    /**自动完成**/
    autoComplete?: string;
    ref?: any;
}
export interface InputProps extends InputBaseProps {
    /**password自定义**/
    password?: PasswordType;
    /**textarea自适应高度 **/
    autoSize?: boolean | {
        minRows?: number;
        maxRows?: number;
    };
    /**行**/
    rows?: number | string;
    /**规定文本区域的宽度（以平均字符宽度计）。默认值是 20。**/
    cols?: number | string;
    /**resize类型**/
    resize?: InputResize;
    /**允许正数**/
    allowPositive?: boolean;
    /**允许负数**/
    allowNegative?: boolean;
    /**允许0**/
    allowZero?: boolean;
    /**允许浮点数**/
    allowFloat?: boolean;
    /**允许001这样的形式**/
    allowZeroStart?: boolean;
    /**数字输入框的up和down 图标是否默认显示**/
    upAndDownDefaultVisible?: boolean;
}
export interface InputStates {
    fitSizePadding?: string;
    passwordType?: boolean;
    placeholderVisible?: boolean;
    height?: number;
    width?: number;
    style?: React.CSSProperties;
    isClearVisible?: boolean;
}
export interface InputPropsWidthRef extends InputProps, ForwardRef {
}
export default class Input extends React.Component<InputPropsWidthRef, InputStates> {
    protected inputRef: RefObject<HTMLInputElement>;
    state: InputStates;
    /**
     * 构造函数
     * @param props
     */
    constructor(props: InputPropsWidthRef);
    static contextType: React.Context<any>;
    static defaultProps: {
        type: string;
        disabled: boolean;
        bordered: boolean;
        trim: boolean;
        autoComplete: string;
        size: string;
        fitSize: boolean;
        maxLengthTextVisible: boolean;
        password: {
            showPassword: boolean;
            focusBlurChangePasswordType: boolean;
        };
    };
    /**
     * 处理点击事件
     * @param e
     */
    handleClick(e: React.MouseEvent<HTMLDivElement>): void;
    /**
     * 键盘落下事件
     * @param e
     */
    handleKeyDown(e: React.KeyboardEvent<HTMLInputElement> & React.KeyboardEvent<HTMLTextAreaElement>): void;
    /**
     * 值改变事件
     * @param e
     */
    handleChange(e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>): void;
    /***
     * 处理正则判断输入
     */
    handleInput(e: React.FormEvent<HTMLInputElement>): void;
    /**
     * 处理聚焦事件
     * @param e
     */
    handleFocus(e: React.FocusEvent<HTMLInputElement>): void;
    /**
     * 处理失去焦点事件
     * @param e
     */
    handleBlur(e: React.FocusEvent<HTMLInputElement | HTMLTextAreaElement>): void;
    /**
     *将输入框置空
     */
    handleClear(e: React.MouseEvent<HTMLElement>): void;
    /**
     * @param renderProps
     * @param classes
     */
    renderRealInput(renderProps: ObjectType, classes: string): React.ReactElement;
    /**
     * 得到计算后的限制文本
     */
    getLimitText(): string;
    /**
     * 渲染函数
     */
    render(): React.ReactNode;
}
export {};
